package javax.management.openmbean;

import java.util.Arrays;
import javax.management.MBeanParameterInfo;
import javax.management.Descriptor;
import javax.management.MBeanConstructorInfo;

public class OpenMBeanConstructorInfoSupport extends MBeanConstructorInfo implements OpenMBeanConstructorInfo
{
    static final long serialVersionUID = -4400441579007477003L;
    private transient Integer myHashCode;
    private transient String myToString;
    
    public OpenMBeanConstructorInfoSupport(String s, String s2, OpenMBeanParameterInfo[] array) {
        this(s, s2, array, (Descriptor)null);
    }
    
    public OpenMBeanConstructorInfoSupport(String name, String description, OpenMBeanParameterInfo[] array, Descriptor descriptor) {
        super(name, description, arrayCopyCast(array), descriptor);
        this.myHashCode = null;
        this.myToString = null;
        if (name == null || name.trim().equals("")) {
            throw new IllegalArgumentException("Argument name cannot be null or empty");
        }
        if (description == null || description.trim().equals("")) {
            throw new IllegalArgumentException("Argument description cannot be null or empty");
        }
        return;
    }
    
    private static MBeanParameterInfo[] arrayCopyCast(OpenMBeanParameterInfo[] array) {
        if (array == null) {
            return null;
        }
        MBeanParameterInfo[] array2 = new MBeanParameterInfo[array.length];
        System.arraycopy(array, 0, array2, 0, array.length);
        return array2;
    }
    
    @Override
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        OpenMBeanConstructorInfo openMBeanConstructorInfo;
        try {
            openMBeanConstructorInfo = (OpenMBeanConstructorInfo)o;
        }
        catch (ClassCastException ex) {
            return false;
        }
        return this.getName().equals(openMBeanConstructorInfo.getName()) && Arrays.equals(this.getSignature(), openMBeanConstructorInfo.getSignature());
    }
    
    @Override
    public int hashCode() {
        if (this.myHashCode == null) {
            this.myHashCode = Integer.valueOf(0 + this.getName().hashCode() + Arrays.asList(this.getSignature()).hashCode());
        }
        return (int)this.myHashCode;
    }
    
    @Override
    public String toString() {
        if (this.myToString == null) {
            this.myToString = this.getClass().getName() + "(name=" + this.getName() + ",signature=" + Arrays.asList(this.getSignature()).toString() + ",descriptor=" + this.getDescriptor() + ")";
        }
        return this.myToString;
    }
}
